==> haskell-x11-1.10.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11
version:              1.10.1
visibility:           public
id:                   X11-1.10.1-KOexKqfvsIxF1vDZupKBH4
key:                  X11-1.10.1-KOexKqfvsIxF1vDZupKBH4
license:              BSD-3-Clause
copyright:
    Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
    Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.

maintainer:           Daniel Wagner <daniel@wagner-home.com>
homepage:             https://github.com/xmonad/X11
synopsis:             A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.

category:             Graphics
abi:                  e1fb7c45ed59278d9058c2b42b35994b
exposed:              True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr

hidden-modules:       Graphics.X11.Xlib.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/X11-1.10.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/X11-1.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/X11-1.10.1
hs-libraries:         HSX11-1.10.1-KOexKqfvsIxF1vDZupKBH4
extra-libraries:      Xss Xinerama Xext X11 Xrandr Xext
include-dirs:         /usr/lib/ghc-9.0.1/site-local/X11-1.10.1/include
includes:             HsXlib.h HsAllKeysyms.h
depends:
    base-4.15.0.0 data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC

ld-options:           "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces:   /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html:         /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.10.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11
version:              1.10.3
visibility:           public
id:                   X11-1.10.3-7zBAfsIL85sJKAyVO3fFRL
key:                  X11-1.10.3-7zBAfsIL85sJKAyVO3fFRL
license:              BSD-3-Clause
copyright:
    Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007,
    Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.

maintainer:           Daniel Wagner <daniel@wagner-home.com>
homepage:             https://github.com/xmonad/X11
synopsis:             A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library. The binding is a direct
    translation of the C binding; for documentation of these calls, refer
    to \"The Xlib Programming Manual\", available online at
    <http://tronche.com/gui/x/xlib/>.

category:             Graphics
abi:                  feb25bd99e22a18e1e08f6fe414a8ac0
exposed:              True
exposed-modules:
    Graphics.X11 Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault Graphics.X11.Types
    Graphics.X11.XScreenSaver Graphics.X11.Xinerama Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Extras Graphics.X11.Xlib.Font
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xrandr

hidden-modules:       Graphics.X11.Xlib.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/X11-1.10.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/X11-1.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-x11
hs-libraries:         HSX11-1.10.3-7zBAfsIL85sJKAyVO3fFRL
extra-libraries:      Xss Xinerama Xext X11 Xrandr Xext
include-dirs:         /usr/lib/ghc-9.0.2/site-local/X11-1.10.3/include
includes:             HsXlib.h HsAllKeysyms.h
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO

ld-options:
    "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now" -flto=auto

haddock-interfaces:   /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html:         /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
